@@ -156,13 +156,16 @@ impl Api {
     pub(crate) async fn register_cluster(
         &self,
         name: &v0::ClusterName,
+        namespace: &str,
         provider: v0::Provider,
         locations: &[Location],
     ) -> ApiResult<v0::Cluster> {
         let name = name.clone();
         let locations = locations.into();
+        let namespace = Some(namespace.to_string());
         let body = v0::CreateClusterDto {
             name,
+            namespace,
             provider,
             locations,
         };
