@@ -10,7 +10,7 @@ use std::hash::{Hash, Hasher};
 use console::Emoji;
 
 const STATE_LABELS: &[Emoji<'static, 'static>] = &[
-    Emoji("☘", "o"),
+    Emoji("☘\u{fe0f}", "o"),
     Emoji("🦍", "o"),
     Emoji("🦧", "o"),
     Emoji("🐕", "o"),
