@@ -457,7 +457,7 @@ impl Cli {
                 cleanup_grace,
             } => {
                 let interactive = !non_interactive;
-                let kubectl = k8s::Kubectl::new().await?;
+                let kubectl = k8s::Kubectl::new()?;
                 for name in &names {
                     if !kubectl.has_context(name) {
                         anyhow::bail!("Context {} is not found in kubeconfig", name)
@@ -521,7 +521,7 @@ impl Cli {
                         "No default Kubernetes context found, need to provide cluster name"
                     )
                 })?;
-                let kubectl = k8s::Kubectl::new().await?;
+                let kubectl = k8s::Kubectl::new()?;
 
                 statehub
                     .update_cluster(kubectl, name, namespace, azure)
@@ -805,7 +805,11 @@ impl StateHub {
         ))?;
 
         let azure = json::to_value(azure)?;
-        let _secret = kubectl.store_azure_credentials(namespace, azure).await?;
+        let _secret = kubectl.store_azure_credentials(&namespace, azure).await?;
+
+        let aws = json::json!({});
+        let _scret = kubectl.store_aws_credentials(&namespace, aws).await?;
+
         Ok(())
     }
 
@@ -1011,8 +1015,7 @@ impl StateHub {
     ) -> anyhow::Result<()> {
         let default_state = default_state.as_deref().unwrap_or("");
         let api = self.api.url("");
-        k8s::Kubectl::with_context(&cluster_name)
-            .await?
+        k8s::Kubectl::with_context(&cluster_name)?
             .store_configmap(
                 &namespace,
                 &cluster_name,
@@ -1026,8 +1029,7 @@ impl StateHub {
     }
 
     async fn list_regions(&self, zone: bool) -> anyhow::Result<()> {
-        k8s::Kubectl::new()
-            .await?
+        k8s::Kubectl::new()?
             .get_regions(zone)
             .await
             .map(|map| {
