@@ -18,22 +18,22 @@ use uuid::Uuid;
 use crate::location::{InvalidRegion, Location};
 use crate::traits::{CloudRegion, Show};
 
-pub use aws::{AwsRegion, PrivateLinkServiceAws};
-pub use azure::{AzureRegion, PrivateLinkServiceAzure};
-pub use cluster::{
+pub use self::aws::{AwsRegion, PrivateLinkServiceAws};
+pub use self::azure::{AzureRegion, PrivateLinkServiceAzure};
+pub use self::cluster::{
     Cluster, ClusterLocationAws, ClusterLocationAzure, ClusterLocations, ClusterName, ClusterToken,
     CreateClusterDto, Provider,
 };
-pub use error::{Error, Permission, StatehubError};
-pub use gcp::GcpRegion;
-pub use helm::Helm;
-pub use login::Login;
-pub use state::{
+pub use self::error::{Error, Permission, StatehubError};
+pub use self::gcp::GcpRegion;
+pub use self::helm::Helm;
+pub use self::login::Login;
+pub use self::state::{
     Condition, CreateStateDto, CreateStateLocationAwsDto, CreateStateLocationAzureDto,
     CreateStateLocationsDto, ProvisioningStatus, State, StateLocationAws, StateLocationAzure,
     StateLocationStatus, StateLocations, StateName,
 };
-pub use volume::{
+pub use self::volume::{
     CreateVolumeDto, LocationVolumeStatus, StateLocationVolumeProgress, Volume, VolumeBindingMode,
     VolumeFileSystem, VolumeLocation, VolumeName, VolumeStatus,
 };
